﻿using System;
using System.Collections.Generic;
using YKPrintService.Service;
using YKPrintService.VO;

namespace PrintServiceTest
{
    /// <summary>
    /// Printer management
    /// </summary>
    public class XpsdkOtherApiDemo
    {
        /// <summary>
        /// Print service object instantiation
        /// </summary>
        private static PrintService service = new PrintService();

        /// <summary>
        /// add printers in batch
        /// </summary>
        public static void addPrinters()
        {
            AddPrinterRequest request = new AddPrinterRequest();
            // Add public parameters
            Config.createRequestHeader(request);

            //Printer list
            List<AddPrinterRequestItem> itemList = new List<AddPrinterRequestItem>();

            AddPrinterRequestItem item = new AddPrinterRequestItem();
            //Invalid printer number, here is just to illustrate the use of interface return parameters, in actual development, valid printer numbers are used here
            item.Sn = "111";
            item.Name = "X58A";
            itemList.Add(item);

            item = new AddPrinterRequestItem();
            //*Required*: The printer number must be a real printer number,
            // otherwise it will cause the subsequent api to fail to print
            item.Sn = Config.OK_PRINTER_SN;
            //Printer name
            item.Name = "X58B";
            itemList.Add(item);


            //*Required*: Array elements are json objects.
            //{"cardno": "traffic card number", "idcode": "printer identifying code","name":"printer name", "sn":"serial number of printer"}
            //The fields of sn and name are required, and a maximum 50 sets can be added each time.
            AddPrinterRequestItem[] items = new AddPrinterRequestItem[itemList.Count];
            request.Items = itemList.ToArray();

            ObjectRestResponse<PrinterResult> resp = service.addPrinters(request);
            //resp.data: Return one json object, including success and failure information, see https://www.xpyun.net/open/index.html example
            //{"code":0,"msg":"ok","data":{"success":["UffietiT46XF2u4","I3kHP4RMcL5jU39"],"fail":["111"]},"serverExecutedTime":0}
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// set voice type for printer
        /// voice type: 0:live big, 1:live middle, 2:live small, 3:beep, 4:muted
        /// </summary>
        public static void setVoiceType()
        {
            SetVoiceTypeRequest request = new SetVoiceTypeRequest();
            Config.createRequestHeader(request);
            //The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            //Voice type: 0 human voice (loud) 1 human voice (medium) 2 human voice (low) 3 Ticking  4 Mute sound
            request.VoiceType = 0;
            ObjectRestResponse<Boolean> resp = service.setPrinterVoiceType(request);
            //resp.data: Return to a Boolean type: true indicates a successful setting and false indicates a failed setting.
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// delete printer in batch
        /// </summary>
        public static void delPrinters()
        {
            DelPrinterRequest request = new DelPrinterRequest();
            Config.createRequestHeader(request);
            //*Required*: A set of printer serial number, which is string array.
            String[] snlist = new String[1];
            //*Required*: The serial number of the printer
            snlist[0] = Config.OK_PRINTER_SN;
            request.Snlist = snlist;
            ObjectRestResponse<PrinterResult> resp = service.delPrinters(request);
            //resp.data: Return one json object, including success and failure information, see https://www.xpyun.net/open/index.html example
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// modify information of your printer
        /// </summary>
        public static void updPrinter()
        {
            UpdPrinterRequest request = new UpdPrinterRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            //*Required*: Name of the printer
            request.Name = "X58C12";

            ObjectRestResponse<Boolean> resp = service.updPrinter(request);
            //resp.data: Return to a Boolean type: true indicates a successful setting and false indicates a failed setting.
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// clear printer queue
        /// </summary>
        public static void delPrinterQueue()
        {
            PrinterRequest request = new PrinterRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            ObjectRestResponse<Boolean> resp = service.delPrinterQueue(request);
            //resp.data: Return to a Boolean type: true indicates a successful setting and false indicates a failed setting.
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// check if the order is printed successfully
        /// </summary>
        public static void queryOrderState()
        {
            QueryOrderStateRequest request = new QueryOrderStateRequest();
            Config.createRequestHeader(request);
            //*Required*: The order ID is returned by the “print order” interface.
            request.OrderId = "OM19111303591262210878";
            ObjectRestResponse<Boolean> resp = service.queryOrderState(request);
            //resp.data: True indicates return after printed and false indicates return not printed.
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// query order statistics for printer on a certain day
        /// </summary>
        public static void queryOrderStatis()
        {
            QueryOrderStatisRequest request = new QueryOrderStatisRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            //*Required*: Query date, format in yyyy-MM-dd, e.g. 2020-09-09
            request.Date = "2020-09-09";
            ObjectRestResponse<OrderStatisResult> resp = service.queryOrderStatis(request);
            //resp.data: Json object, return the order quantity printed and to be printed, e.g. {"printed": 2,"waiting": 0}
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// query status of printer
        /// </summary>
        public static void queryPrinterStatus()
        {
            PrinterRequest request = new PrinterRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            ObjectRestResponse<int> resp = service.queryPrinterStatus(request);
            //resp.data:Return to the printer status value, three types in total:
            //0 indicates offline status.
            //1 indicates online and normal status.
            //2 indicates online and abnormal status.
            //Remarks: Abnormal status means lack of paper, if the printer has been out of contact with the server for more than 30s, it can be confirmed to be offline status.
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// query status of printer
        /// </summary>
        public static void queryPrintersStatus()
        {
            PrintersRequest request = new PrintersRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            List<String> snlist = new List<string>();
            //XXXXXXXXXXX Indicates the actual equipment number
            snlist.Add("XXXXXXXXXXX");
            snlist.Add("XXXXXXXXXXX");
            snlist.Add("XXXXXXXXXXX");
            request.Snlist = snlist;
            ObjectRestResponse<List<int>> resp = service.queryPrintersStatus(request);
            //resp.data:Return to the printer status value, three types in total:
            //0 indicates offline status.
            //1 indicates online and normal status.
            //2 indicates online and abnormal status.
            //Remarks: Abnormal status means lack of paper, if the printer has been out of contact with the server for more than 30s, it can be confirmed to be offline status.
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// Amount broadcast
        /// </summary>
        public static void playVoice()
        {
            VoiceRequest request = new VoiceRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            //payment method:
            //Value range 41~55:
            //Alipay 41, WeChat 42, Cloud Payment 43, UnionPay Swipe 44, UnionPay Payment 45, Member Card Consumption 46, Member Card Recharge 47, Yipay 48, Successful Collection 49, Jialian Payment 50, One Wallet 51, JD Pay 52, Quick money payment 53, Granville payment 54, Xiangqian payment 55
            //It is only used for Xinye cloud printers that support the amount broadcast.
            request.PayType = 41;
            //Pay or not:
            //Value range 59~61:
            //Refund 59 to account 60 consumption 61.
            //It is only used for Xinye cloud printers that support the amount broadcast.
            request.PayMode = 59;
            //Payment amount:
            //Up to 2 decimal places are allowed.
            //It is only used for Xinye cloud printers that support the amount broadcast.
            request.Money = 24.15;
            ObjectRestResponse<String> resp = service.playVoice(request);
            //resp.data:Returns 0 correctly
            Console.WriteLine(resp.Msg);
        }
    }
}
