﻿using System;
using System.Text;
using YKPrintService.Service;
using YKPrintService.VO;

namespace PrintServiceTest
{
    /// <summary>
    /// Print example
    /// </summary>
    public class XpsdkPrintApiDemo
    {
        /// <summary>
        /// Print service object instantiation
        /// </summary>
        private static PrintService service = new PrintService();
        /// <summary>
        /// Example of font alignment for small ticket printing, don't support amount broadcast
        /// Note: Do not use the alignment labels L C R CB in nesting. The inner label is valid while the outer label is invalid;
        /// Do not use multiple alignment labels in the same row, otherwise only the last alignment label is valid
        /// </summary>
        public static void printFontAlign()
        {
            /**
             * <BR>：Line break (a closing tag on the same line (such as </C>) should be placed before the closing tag, two consecutive line breaks <BR><BR> can mean adding a blank line)
             *  <L></L>：Align left
             *  <C></C>：Align center
             *  <R></R>：Align right
             *  Note: Multiple alignment methods cannot be used for the same line of content, and the alignment style can be customized by adding spaces.
             *       58mm machine, 16 Chinese characters and 32 letters can be printed in one line
             *       80mm machine, print 24 Chinese characters and 48 letters in one line
             *
             *  <N></N>：Normal font size
             *  <HB></HB>：double font in height
             *  <WB></WB>：double font in width
             *  <B></B>：double font in size
             *  <CB></CB>：double font in size centred
             *  <HB2></HB2>：Triple font height
             *  <WB2></WB2>：Triple font width
             *  <B2></B2>：Triple font size
             *  <BOLD></BOLD>：bold font
             *  <LOGO></LOGO>：logo (the tag content is a character string in Base64 format, temporarily not opened)
             *  <QR></QR>：QR code (the label content is the value of the QR code, the maximum cannot exceed 256 characters, and a single order can only print one QR code).
             *             QR code width setting: It can be customized by <QR> tag name, for example, <QR180> means the width is 180, and the corresponding closed tag </QR>
             *             No need to specify width. The <QR> tag does not specify a width, the default is 110, the minimum is 90, and the maximum is 180
             *  <BARCODE></BARCODE>：Barcode (the content of the label is the barcode value)
             */
            StringBuilder printContent = new StringBuilder();
            printContent.Append("no element：").Append("default font<BR>");

            printContent.Append("<BR>");
            printContent.Append("L element：").Append("<L>Align left<BR></L>");
            printContent.Append("<BR>");
            printContent.Append("R element：").Append("<R>Align right<BR></R>");
            printContent.Append("<BR>");
            printContent.Append("C element：").Append("<C>Align center<BR></C>");

            printContent.Append("<BR>");
            printContent.Append("N element：").Append("<N>Normal font size<BR></N>");
            printContent.Append("<BR>");
            printContent.Append("HB element：").Append("<HB>Double font height<BR></HB>");
            printContent.Append("<BR>");
            printContent.Append("WB element：").Append("<WB>Double font width<BR></WB>");
            printContent.Append("<BR>");
            printContent.Append("B element：").Append("<B>Double font size<BR></B>");
            printContent.Append("<BR>");
            printContent.Append("HB2 element：").Append("<HB2>Triple font height<BR></HB2>");
            printContent.Append("<BR>");
            printContent.Append("WB2 element：").Append("<WB2>Triple font width<BR></WB2>");
            printContent.Append("<BR>");
            printContent.Append("B2 element：").Append("<B2>Triple font size<BR></B2>");
            printContent.Append("<BR>");
            printContent.Append("BOLD element：").Append("<BOLD>Bold font<BR></BOLD>");

            // neseted using font and align element
            printContent.Append("<BR>");
            printContent.Append("<C>Nested use:").Append("<BOLD>Center bold</BOLD>").Append("<BR></C>");

            // Print barcodes and QR codes
            printContent.Append("<BR>");
            printContent.Append("<C><BARCODE>9884822189</BARCODE></C>");
            printContent.Append("<C><QR>https://www.xpyun.net</QR></C>");


            PrintRequest request = new PrintRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            //*Required*: The content to be printed can’t exceed 12288 bytes.
            request.Content = printContent.ToString();
            //The number of printed copies is 1 by default.
            request.Copies = 1;
            //Sound playback mode, 0 for cancel the order mode, 1 for mute mode, 2 for single playback mode,3. Apply for refund for some users. default is 2 for single playback mode
            request.Voice = 2;
            //Print mode:
            //If the value is 0 or not specified, it will check whether the printer is online. If not online, it will not generate a print order and directly return the status code of an offline device.
            //If online, it will generate a print order and return the print order number.If the value is 1, it will not check whether the printer is online, directly generate a print order and return the print order number.
            //If the printer is not online, the order will be cached in the print queue and will be printed automatically when the printer is normally online.
            request.Mode = 0;
            ObjectRestResponse<String> resp = service.print(request);
            //resp.data: Return to order No. correctly
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// Example of font alignment for small ticket printing, support amount broadcast
        /// Note: Do not use the alignment labels L C R CB in nesting. The inner label is valid while the outer label is invalid;
        /// Do not use multiple alignment labels in the same row, otherwise only the last alignment label is valid
        /// </summary>
        public static void printFontAlignVoiceSupport()
        {
            /**
             * <BR>：Line break (a closing tag on the same line (such as </C>) should be placed before the closing tag, two consecutive line breaks <BR><BR> can mean adding a blank line)
             *  <L></L>：Align left
             *  <C></C>：Align center
             *  <R></R>：Align right
             *  Note: Multiple alignment methods cannot be used for the same line of content, and the alignment style can be customized by adding spaces.
             *       58mm machine, 16 Chinese characters and 32 letters can be printed in one line
             *       80mm machine, print 24 Chinese characters and 48 letters in one line
             *
             *  <N></N>：Normal font size
             *  <HB></HB>：double font in height
             *  <WB></WB>：double font in width
             *  <B></B>：double font in size
             *  <CB></CB>：double font in size centred
             *  <HB2></HB2>：Triple font height
             *  <WB2></WB2>：Triple font width
             *  <B2></B2>：Triple font size
             *  <BOLD></BOLD>：bold font
             *  <LOGO></LOGO>：logo (the tag content is a character string in Base64 format, temporarily not opened)
             *  <QR></QR>：QR code (the label content is the value of the QR code, the maximum cannot exceed 256 characters, and a single order can only print one QR code).
             *             QR code width setting: It can be customized by <QR> tag name, for example, <QR180> means the width is 180, and the corresponding closed tag </QR>
             *             No need to specify width. The <QR> tag does not specify a width, the default is 110, the minimum is 90, and the maximum is 180
             *  <BARCODE></BARCODE>：Barcode (the content of the label is the barcode value)
             */
            StringBuilder printContent = new StringBuilder();
            printContent.Append("no element：").Append("default font<BR>");

            printContent.Append("<BR>");
            printContent.Append("L element：").Append("<L>Align left<BR></L>");
            printContent.Append("<BR>");
            printContent.Append("R element：").Append("<R>Align right<BR></R>");
            printContent.Append("<BR>");
            printContent.Append("C element：").Append("<C>Align center<BR></C>");

            printContent.Append("<BR>");
            printContent.Append("N element：").Append("<N>Normal font size<BR></N>");
            printContent.Append("<BR>");
            printContent.Append("HB element：").Append("<HB>Double font height<BR></HB>");
            printContent.Append("<BR>");
            printContent.Append("WB element：").Append("<WB>Double font width<BR></WB>");
            printContent.Append("<BR>");
            printContent.Append("B element：").Append("<B>Double font size<BR></B>");
            printContent.Append("<BR>");
            printContent.Append("HB2 element：").Append("<HB2>Triple font height<BR></HB2>");
            printContent.Append("<BR>");
            printContent.Append("WB2 element：").Append("<WB2>Triple font width<BR></WB2>");
            printContent.Append("<BR>");
            printContent.Append("B2 element：").Append("<B2>Triple font size<BR></B2>");
            printContent.Append("<BR>");
            printContent.Append("BOLD element：").Append("<BOLD>Bold font<BR></BOLD>");

            // neseted using font and align element
            printContent.Append("<BR>");
            printContent.Append("<C>Nested use:").Append("<BOLD>Center bold</BOLD>").Append("<BR></C>");

            // Print barcodes and QR codes
            printContent.Append("<BR>");
            printContent.Append("<C><BARCODE>9884822189</BARCODE></C>");
            printContent.Append("<C><QR>https://www.xpyun.net</QR></C>");

            PrintRequest request = new PrintRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            //*Required*: The content to be printed can’t exceed 12288 bytes.
            request.Content = printContent.ToString();
            //The number of printed copies is 1 by default.
            request.Copies = 1;
           //Sound playback mode, 0 for cancel the order mode, 1 for mute mode, 2 for single playback mode,3. Apply for refund for some users. default is 2 for single playback mode
            request.Voice = 2;
            //Print mode:
            //If the value is 0 or not specified, it will check whether the printer is online. If not online, it will not generate a print order and directly return the status code of an offline device.
            //If online, it will generate a print order and return the print order number.If the value is 1, it will not check whether the printer is online, directly generate a print order and return the print order number.
            //If the printer is not online, the order will be cached in the print queue and will be printed automatically when the printer is normally online.
            request.Mode = 0;

            //payment method:
            //Value range 41~55:
            //Alipay 41, WeChat 42, Cloud Payment 43, UnionPay Swipe 44, UnionPay Payment 45, Member Card Consumption 46, Member Card Recharge 47, Yipay 48, Successful Collection 49, Jialian Payment 50, One Wallet 51, JD Pay 52, Quick money payment 53, Granville payment 54, Xiangqian payment 55
            //It is only used for Xinye cloud printers that support the amount broadcast.
            request.PayType = 41;
            //Pay or not:
            //Value range 59~61:
            //Refund 59 to account 60 consumption 61.
            //It is only used for Xinye cloud printers that support the amount broadcast.
            request.PayMode = 60;
            //Payment amount:
            //Up to 2 decimal places are allowed.
            //It is only used for Xinye cloud printers that support the amount broadcast.
            request.Money = 20.15;

            ObjectRestResponse<String> resp = service.print(request);
            //resp.data: Return to order No. correctly
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// complex alignment sample for note, don't support amount broadcast
        /// notice: 58mm printer can print 32 characters per line
        /// </summary>
        public static void printComplexReceipt()
        {
            /**
             * <BR>：Line break (a closing tag on the same line (such as </C>) should be placed before the closing tag, two consecutive line breaks <BR><BR> can mean adding a blank line)
             *  <L></L>：Align left
             *  <C></C>：Align center
             *  <R></R>：Align right
             *  Note: Multiple alignment methods cannot be used for the same line of content, and the alignment style can be customized by adding spaces.
             *       58mm machine, 16 Chinese characters and 32 letters can be printed in one line
             *       80mm machine, print 24 Chinese characters and 48 letters in one line
             *
             *  <N></N>：Normal font size
             *  <HB></HB>：double font in height
             *  <WB></WB>：double font in width
             *  <B></B>：double font in size
             *  <CB></CB>：double font in size centred
             *  <HB2></HB2>：Triple font height
             *  <WB2></WB2>：Triple font width
             *  <B2></B2>：Triple font size
             *  <BOLD></BOLD>：bold font
             *  <LOGO></LOGO>：logo (the tag content is a character string in Base64 format, temporarily not opened)
             *  <QR></QR>：QR code (the label content is the value of the QR code, the maximum cannot exceed 256 characters, and a single order can only print one QR code).
             *             QR code width setting: It can be customized by <QR> tag name, for example, <QR180> means the width is 180, and the corresponding closed tag </QR>
             *             No need to specify width. The <QR> tag does not specify a width, the default is 110, the minimum is 90, and the maximum is 180
             *  <BARCODE></BARCODE>：Barcode (the content of the label is the barcode value)
             */
            StringBuilder printContent = new StringBuilder();

            printContent.Append("<C>").Append("<B>xpyun receipt</B>").Append("<BR></C>");
            printContent.Append("<BR>");

            printContent.Append("name").Append(NoteFormatter.repeat(" ", 16))
                    .Append("count").Append(NoteFormatter.repeat(" ", 1))
                    .Append("price").Append(NoteFormatter.repeat(" ", 1))
                    .Append("<BR>");
            printContent.Append(NoteFormatter.repeat("-", 32)).Append("<BR>");
            printContent.Append(NoteFormatter.formatPrintOrderItem("Stewed Ribs", 2, 9.99));
            printContent.Append(NoteFormatter.formatPrintOrderItem("Boiled Fish", 1, 108.0));
            printContent.Append(NoteFormatter.formatPrintOrderItem("Braised Codfish with Mushrooms", 1, 99.9));
            printContent.Append(NoteFormatter.formatPrintOrderItem("Braised Squid", 5, 19.99));
            printContent.Append(NoteFormatter.repeat("-", 32)).Append("<BR>");
            printContent.Append("<R>").Append("total：").Append("$327.83").Append("<BR></R>");

            printContent.Append("<BR>");
            printContent.Append("<L>")
                    .Append("address：").Append("Broadway, New York City").Append("<BR>")
                    .Append("phone：").Append("1363*****88").Append("<BR>")
                    .Append("orderTime：").Append("2020-9-9 15:07:57").Append("<BR>")
                    .Append("remarks：").Append("Less spicy").Append("<BR>");

            printContent.Append("<C>")
                    .Append("<QR>https://www.xpyun.net</QR>")
                    .Append("</C>");

            PrintRequest request = new PrintRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            //*Required*: The content to be printed can’t exceed 12288 bytes.
            request.Content = printContent.ToString();
            //The number of printed copies is 1 by default.
            request.Copies = 1;
            //Sound playback mode, 0 for cancel the order mode, 1 for mute mode, 2 for single playback mode,3. Apply for refund for some users. default is 2 for single playback mode
            request.Voice = 2;
            //Print mode:
            //If the value is 0 or not specified, it will check whether the printer is online. If not online, it will not generate a print order and directly return the status code of an offline device.
            //If online, it will generate a print order and return the print order number.If the value is 1, it will not check whether the printer is online, directly generate a print order and return the print order number.
            //If the printer is not online, the order will be cached in the print queue and will be printed automatically when the printer is normally online.
            request.Mode = 0;

            ObjectRestResponse<String> resp = service.print(request);
            //resp.data: Return to order No. correctly
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// complex alignment sample for note, support amount broadcast
        /// notice: 58mm printer can print 32 characters per line
        /// </summary>
        public static void printComplexReceiptVoiceSupport()
        {
            /**
             * <BR>：Line break (a closing tag on the same line (such as </C>) should be placed before the closing tag, two consecutive line breaks <BR><BR> can mean adding a blank line)
             *  <L></L>：Align left
             *  <C></C>：Align center
             *  <R></R>：Align right
             *  Note: Multiple alignment methods cannot be used for the same line of content, and the alignment style can be customized by adding spaces.
             *       58mm machine, 16 Chinese characters and 32 letters can be printed in one line
             *       80mm machine, print 24 Chinese characters and 48 letters in one line
             *
             *  <N></N>：Normal font size
             *  <HB></HB>：double font in height
             *  <WB></WB>：double font in width
             *  <B></B>：double font in size
             *  <CB></CB>：double font in size centred
             *  <HB2></HB2>：Triple font height
             *  <WB2></WB2>：Triple font width
             *  <B2></B2>：Triple font size
             *  <BOLD></BOLD>：bold font
             *  <LOGO></LOGO>：logo (the tag content is a character string in Base64 format, temporarily not opened)
             *  <QR></QR>：QR code (the label content is the value of the QR code, the maximum cannot exceed 256 characters, and a single order can only print one QR code).
             *             QR code width setting: It can be customized by <QR> tag name, for example, <QR180> means the width is 180, and the corresponding closed tag </QR>
             *             No need to specify width. The <QR> tag does not specify a width, the default is 110, the minimum is 90, and the maximum is 180
             *  <BARCODE></BARCODE>：Barcode (the content of the label is the barcode value)
             */
            StringBuilder printContent = new StringBuilder();

            printContent.Append("<C>").Append("<B>xpyun receipt</B>").Append("<BR></C>");
            printContent.Append("<BR>");

            printContent.Append("name").Append(NoteFormatter.repeat(" ", 16))
                    .Append("count").Append(NoteFormatter.repeat(" ", 1))
                    .Append("price").Append(NoteFormatter.repeat(" ", 1))
                    .Append("<BR>");
            printContent.Append(NoteFormatter.repeat("-", 32)).Append("<BR>");
            printContent.Append(NoteFormatter.formatPrintOrderItem("Stewed Ribs", 2, 9.99));
            printContent.Append(NoteFormatter.formatPrintOrderItem("Boiled Fish", 1, 108.0));
            printContent.Append(NoteFormatter.formatPrintOrderItem("Braised Codfish with Mushrooms", 1, 99.9));
            printContent.Append(NoteFormatter.formatPrintOrderItem("Braised Squid", 5, 19.99));
            printContent.Append(NoteFormatter.repeat("-", 32)).Append("<BR>");
            printContent.Append("<R>").Append("total：").Append("$327.83").Append("<BR></R>");

            printContent.Append("<BR>");
            printContent.Append("<L>")
                    .Append("address：").Append("Broadway, New York City").Append("<BR>")
                    .Append("phone：").Append("1363*****88").Append("<BR>")
                    .Append("orderTime：").Append("2020-9-9 15:07:57").Append("<BR>")
                    .Append("remarks：").Append("Less spicy").Append("<BR>");

            printContent.Append("<C>")
                    .Append("<QR>https://www.xpyun.net</QR>")
                    .Append("</C>");

            PrintRequest request = new PrintRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            //*Required*: The content to be printed can’t exceed 12288 bytes.
            request.Content = printContent.ToString();
            //The number of printed copies is 1 by default.
            request.Copies = 1;
            //Sound playback mode, 0 for cancel the order mode, 1 for mute mode, 2 for single playback mode,3. Apply for refund for some users. default is 2 for single playback mode
            request.Voice = 2;
            //Print mode:
            //If the value is 0 or not specified, it will check whether the printer is online. If not online, it will not generate a print order and directly return the status code of an offline device.
            //If online, it will generate a print order and return the print order number.If the value is 1, it will not check whether the printer is online, directly generate a print order and return the print order number.
            //If the printer is not online, the order will be cached in the print queue and will be printed automatically when the printer is normally online.
            request.Mode = 0;

            //payment method:
            //Value range 41~55:
            //Alipay 41, WeChat 42, Cloud Payment 43, UnionPay Swipe 44, UnionPay Payment 45, Member Card Consumption 46, Member Card Recharge 47, Yipay 48, Successful Collection 49, Jialian Payment 50, One Wallet 51, JD Pay 52, Quick money payment 53, Granville payment 54, Xiangqian payment 55
            //It is only used for Xinye cloud printers that support the amount broadcast.
            request.PayType = 41;
            //Pay or not:
            //Value range 59~61:
            //Refund 59 to account 60 consumption 61.
            //It is only used for Xinye cloud printers that support the amount broadcast.
            request.PayMode = 60;
            //Payment amount:
            //Up to 2 decimal places are allowed.
            //It is only used for Xinye cloud printers that support the amount broadcast.
            request.Money = 20.15;

            ObjectRestResponse<String> resp = service.print(request);
            //resp.data: Return to order No. correctly
            Console.WriteLine(resp.Msg);
        }

        /// <summary>
        /// comprehensive layout sample for label printing
        /// How to determine the coordinates?
        /// The origin of the coordinates is at the upper left corner, the x-axis is from left to right,
        /// and the y-axis is from top to bottom;
        /// According to the test, the maximum value of the x-axis is equal to the width of the label paper
        /// multiplied by 8, and the maximum value of the y-axis is equal to the height of the label paper multiplied by 8.
        /// For example, the label size is 40*30, the maximum value of x-axis=40*8=320, the maximum value of y-axis=30*8=240
        /// Users need to typeset according to actual paper size and their requirements
        ///
        /// The greater than and less than signs in the printed content(except labels) need to be translated before they can be printed normally.
        /// Among them, "<" is represented by "&lt", and ">" is represented by "&gt"; 1mm=8dots.
        /// </summary>
        public static void printLabel()
        {
            /**
             * <PAGE></PAGE>：
             *  Pagination, used to support the printing of multiple different label pages (up to 10 sheets), not using this label means that all elements are only printed on one label page
             *
             *  <SIZE>width,height</SIZE>：
             *  Set label paper width and height, width label paper width (excluding backing paper), height label paper height (excluding backing paper), unit mm, such as<SIZE>40,30</SIZE>
             *
             *  <TEXT x="10" y="100" w="1" h="2" r="0">Text content</TEXT>：
             *  Print the text, where:
             *  The attribute x is the coordinate of the starting point in the horizontal direction (default is 0)
             *  Attribute y is the starting point coordinate in the vertical direction (default is 0)
             *  The attribute w is the text width magnification ratio 1-10 (default is 1)
             *  Attribute h is text height magnification 1-10 (default is 1)
             *  The attribute r is the rotation angle of the text (clockwise, the default is 0):
             *  0     0degree
             *  90   90degree
             *  180 180degree
             *  270 270degree
             *
             *  <BC128 x="10" y="100" h="60" s="1" n="1" w="1" r="0">1234567</BC128>：
             *  Print code128 one-dimensional code, where:
             *  The attribute x is the coordinate of the starting point in the horizontal direction (default is 0)
             *  Attribute y is the starting point coordinate in the vertical direction (default is 0)
             *  The attribute h is the height of the barcode (default is 48)
             *  Whether the attribute s can be recognized by human eyes: 0 is not recognized, 1 is recognized (default is 1)
             *  The attribute n is the width of the narrow bar, expressed in dots (default is 1)
             *  The attribute w is the width of bar, expressed in dots (default is 1)
             *  The attribute r is the text rotation angle (clockwise, the default is 0):
             *  0     0degree
             *  90   90degree
             *  180 180degree
             *  270 270degree
             *
             *  <BC39 x="10" y="100" h="60" s="1" n="1" w="1" r="0">1234567</BC39>：
             *  Print code39 one-dimensional code, where:
             *  The attribute x is the coordinate of the starting point in the horizontal direction (default is 0)
             *  Attribute y is the starting point coordinate in the vertical direction (default is 0)
             *  The attribute h is the height of the barcode (default is 48)
             *  Whether the attribute s can be recognized by human eyes: 0 is not recognized, 1 is recognized (default is 1)
             *  The attribute n is the width of the narrow bar, expressed in dots (default is 1)
             *  The attribute w is the width of bar, expressed in dots (default is 2)
             *  The attribute r is the rotation angle of the text (clockwise, the default is 0):
             *  0     0degree
             *  90   90degree
             *  180 180degree
             *  270 270degree
             *
             *  <QR x="20" y="20" w="160" e="H">QR code content</QR>：
             *  Print the QR code, where:
             *  The attribute x is the coordinate of the starting point in the horizontal direction (default is 0)
             *  Attribute y is the starting point coordinate in the vertical direction (default is 0)
             *  The attribute w is the width of the QR code (default is 160)
             *  Attribute e is the error correction level: L 7% M 15% Q 25% H 30% (the default is H)
             *  The label content is a QR code value, and the maximum cannot exceed 256 characters
             *  Note: A single order can only print one QR code
             */
            StringBuilder printContent = new StringBuilder();

            //print the first label
            printContent.Append("<PAGE>")
	    .Append("<SIZE>40,30</SIZE>") //Set size of label paper
                    .Append("<TEXT x=\"8\" y=\"8\" w=\"1\" h=\"1\" r=\"0\">")
                    .Append("#001").Append(NoteFormatter.repeat(" ", 4))
                    .Append("Table one").Append(NoteFormatter.repeat(" ", 4))
                    .Append("1/3")
                    .Append("</TEXT>")
                    .Append("<TEXT x=\"8\" y=\"96\" w=\"1\" h=\"2\" r=\"0\">")
                    .Append("Golden Fried Rice")
                    .Append("</TEXT>")
                    .Append("<TEXT x=\"8\" y=\"200\" w=\"1\" h=\"1\" r=\"0\">")
                    .Append("Miss Wang").Append(NoteFormatter.repeat(" ", 4))
                    .Append("136****3388")
                    .Append("</TEXT>")
                    .Append("</PAGE>");
            //print the second label
            printContent.Append("<PAGE>")
                    .Append("<TEXT x=\"8\" y=\"8\" w=\"1\" h=\"1\" r=\"0\">")
                    .Append("#001").Append(NoteFormatter.repeat(" ", 4))
                    .Append("Table one").Append(NoteFormatter.repeat(" ", 4))
                    .Append("2/3")
                    .Append("</TEXT>")
                    .Append("<TEXT x=\"8\" y=\"96\" w=\"1\" h=\"2\" r=\"0\">")
                    .Append("Cucumber salad")
                    .Append("</TEXT>")
                    .Append("<TEXT x=\"8\" y=\"200\" w=\"1\" h=\"1\" r=\"0\">")
                    .Append("Miss Wang").Append(NoteFormatter.repeat(" ", 4))
                    .Append("136****3388")
                    .Append("</TEXT>")
                    .Append("</PAGE>");
            //print the third label
            printContent.Append("<PAGE>")
                    .Append("<TEXT x=\"8\" y=\"8\" w=\"1\" h=\"1\" r=\"0\">")
                    .Append("#001").Append(NoteFormatter.repeat(" ", 4))
                    .Append("Table one").Append(NoteFormatter.repeat(" ", 4))
                    .Append("3/3")
                    .Append("</TEXT>")
                    .Append("<TEXT x=\"8\" y=\"96\" w=\"1\" h=\"2\" r=\"0\">")
                    .Append("Boston Lobster")
                    .Append("</TEXT>")
                    .Append("<TEXT x=\"8\" y=\"200\" w=\"1\" h=\"1\" r=\"0\">")
                    .Append("Miss Wang").Append(NoteFormatter.repeat(" ", 4))
                    .Append("136****3388")
                    .Append("</TEXT>")
                    .Append("</PAGE>");
            //print a barcode
            printContent.Append("<PAGE>")
                    .Append("<TEXT x=\"8\" y=\"8\" w=\"1\" h=\"1\" r=\"0\">")
                    .Append("print a barcode：")
                    .Append("</TEXT>")
                    .Append("<BC128 x=\"16\" y=\"32\" h=\"32\" s=\"1\" n=\"2\" w=\"2\" r=\"0\">")
                    .Append("12345678")
                    .Append("</BC128>")
                    .Append("</PAGE>");
            //print a QR code. The minimum width is 128, it will not be able to be scanned if lower than 128
            printContent.Append("<PAGE>")
                    .Append("<TEXT x=\"8\" y=\"8\" w=\"1\" h=\"1\" r=\"0\">")
                    .Append("print a QR code:")
                    .Append("</TEXT>")
                    .Append("<QR x=\"16\" y=\"32\" w=\"128\">")
                    .Append("https://www.xpyun.net")
                    .Append("</QR>")
                    .Append("</PAGE>");

            PrintRequest request = new PrintRequest();
            Config.createRequestHeader(request);
            //*Required*: The serial number of the printer
            request.Sn = Config.OK_PRINTER_SN;
            //*Required*: The content to be printed can’t exceed 12288 bytes.
            request.Content = printContent.ToString();
            //The number of printed copies is 1 by default.
            request.Copies = 1;
            //Sound playback mode, 0 for cancel the order mode, 1 for mute mode, 2 for single playback mode,3. Apply for refund for some users. default is 2 for single playback mode
            request.Voice = 2;

            ObjectRestResponse<String> resp = service.printLabel(request);
            //resp.data: Return to order No. correctly
            Console.WriteLine(resp.Msg);
        }
    }
}
