﻿using System;
using System.Text;

namespace PrintServiceTest
{
    /// <summary>
    /// receipt formatter
    /// </summary>
    public class NoteFormatter
    {
        private static readonly int ROW_MAX_CHAR_LEN = 32;
        private static readonly int MAX_NAME_CHAR_LEN = 20;
        private static readonly int LAST_ROW_MAX_NAME_CHAR_LEN = 16;
        private static readonly int MAX_QUANTITY_CHAR_LEN = 6;
        private static readonly int MAX_PRICE_CHAR_LEN = 6;
        private static String orderNameEmpty = repeat(" ", MAX_NAME_CHAR_LEN);

        /// <summary>
        /// Format the dish list(for 58 mm printer)
        /// Note: this is  default font typesetting, not applicable if the font width is doubled
        /// The 58mm printer can print 32 characters per line
        /// Divided into 3 columns: name(20 characters), quanity(6 characters),price(6 characters)
        /// The name column is generally filled with 16  your characters and 4 spaces
        /// Long name column will cause auto line break
        /// </summary>
        /// <param name="foodName">Dish name</param>
        /// <param name="quantity">Quantity</param>
        /// <param name="price">Price</param>
        /// <returns></returns>
        public static String formatPrintOrderItem(String foodName, int quantity, Double price)
        {
            StringBuilder builder = new StringBuilder();

            byte[] itemNames = Encoding.GetEncoding("gbk").GetBytes(foodName);
            String quanityStr = quantity.ToString();
            byte[] itemQuans = Encoding.GetEncoding("gbk").GetBytes(quanityStr);
            String priceStr = roundByTwo(price);
            byte[] itemPrices = Encoding.GetEncoding("gbk").GetBytes(priceStr);

            builder.Append(foodName);
            int mod = itemNames.Length % ROW_MAX_CHAR_LEN;

            if (mod <= LAST_ROW_MAX_NAME_CHAR_LEN)
            {
                // if  in the same row, fill with 4 spaces at the end of name column
                builder.Append(repeat(" ", (MAX_NAME_CHAR_LEN - mod)));
                builder.Append(quanityStr).Append(repeat(" ", (MAX_QUANTITY_CHAR_LEN - itemQuans.Length)));
                builder.Append(priceStr).Append(repeat(" ", (MAX_PRICE_CHAR_LEN - itemPrices.Length)));
            }
            else
            {
                // new line
                builder.Append("<BR>");
                builder.Append(orderNameEmpty);
                builder.Append(quanityStr).Append(repeat(" ", (MAX_QUANTITY_CHAR_LEN - itemQuans.Length)));
                builder.Append(priceStr).Append(repeat(" ", (MAX_PRICE_CHAR_LEN - itemPrices.Length)));
            }
            builder.Append("<BR>");
            return builder.ToString();
        }

        /// <summary>
        /// Format the double as a String with specified decimal places, fill in with 0 if the decimal place is not enough
        /// </summary>
        /// <param name="v">Number to be formatted</param>
        /// <returns>Returns a string with a specified number of digits</returns>
        public static String roundByTwo(double v)
        {
            return roundByScale(v, 2);
        }

        /// <summary>
        /// Format the double as a String with specified decimal places, and use 0 to complete the decimal places
        /// </summary>
        /// <param name="v">number to be formatted</param>
        /// <param name="scale">places after the decimal point</param>
        /// <returns>Returns a string with a specified number of digits</returns>
        public static String roundByScale(double v, int scale)
        {
            return v.ToString("0.00");
        }

        /// <summary>
        /// Repeat a String {@code repeat} times to form a new String.
        /// </summary>
        /// <param name="character">the String to repeat, may be null</param>
        /// <param name="num">number of times to repeat str, negative treated as zero</param>
        /// <returns>a new String consisting of the original String repeated,{@code null} if null String input</returns>
        public static String repeat(string character, int num)
        {
            return new string(character.ToCharArray()[0], num);
        }

    }
}
