﻿using YKPrintService.VO;
using YKPrintService.Util;
using System;
using System.Collections.Generic;

namespace YKPrintService.Service
{
    /// <summary>
    /// Service interface encapsulation of cloud printing platform
    /// </summary>
    public class PrintService
    {
        private static readonly String BASE_URL = "https://open.xpyun.net";

        /// <summary>
        /// 1.Batch add printer
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<PrinterResult> addPrinters(AddPrinterRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/addPrinters";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<PrinterResult> result = JsonHelper.Json2Object<ObjectRestResponse<PrinterResult>>(resp);
            return result;
        }

        /// <summary>
        /// 2.Sets the printer speech type
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<bool> setPrinterVoiceType(SetVoiceTypeRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/setVoiceType";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<bool> result = JsonHelper.Json2Object<ObjectRestResponse<bool>>(resp);
            return result;
        }

        /// <summary>
        /// 3.Print a small receipt order
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<string> print(PrintRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/print";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<string> result = JsonHelper.Json2Object<ObjectRestResponse<string>>(resp);
            return result;
        }

        /// <summary>
        /// 3.Print Label Order
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<string> printLabel(PrintRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/printLabel";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<string> result = JsonHelper.Json2Object<ObjectRestResponse<string>>(resp);
            return result;
        }


        /// <summary>
        /// 4.Bulk delete printer
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<PrinterResult> delPrinters(DelPrinterRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/delPrinters";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<PrinterResult> result = JsonHelper.Json2Object<ObjectRestResponse<PrinterResult>>(resp);
            return result;
        }

        /// <summary>
        /// 5.Modify printer information
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<Boolean> updPrinter(UpdPrinterRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/updPrinter";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<bool> result = JsonHelper.Json2Object<ObjectRestResponse<bool>>(resp);
            return result;
        }

        /// <summary>
        /// 6.Clear the queue to print
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<bool> delPrinterQueue(PrinterRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/delPrinterQueue";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<bool> result = JsonHelper.Json2Object<ObjectRestResponse<bool>>(resp);
            return result;
        }

        /// <summary>
        /// 7.Query if the order was printed successfully
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<bool> queryOrderState(QueryOrderStateRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/queryOrderState";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<bool> result = JsonHelper.Json2Object<ObjectRestResponse<bool>>(resp);
            return result;
        }

        /// <summary>
        /// 8.Query the order count of the printer for a certain day
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<OrderStatisResult> queryOrderStatis(QueryOrderStatisRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/queryOrderStatis";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<OrderStatisResult> result = JsonHelper.Json2Object<ObjectRestResponse<OrderStatisResult>>(resp);
            return result;
        }

        /// <summary>
        /// 9.Query printer status
        /// 
        /// 0, offline 1, online normal 2, online abnormal
        /// Note: the exception is usually no paper, offline judgment is the printer and the server lost contact for more than 30 seconds
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<int> queryPrinterStatus(PrinterRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/queryPrinterStatus";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<int> result = JsonHelper.Json2Object<ObjectRestResponse<int>>(resp);
            return result;
        }

        /// <summary>
        /// 10.Batch query printer status
        ///
        /// 0, offline 1, online normal 2, online abnormal
        /// Note: the exception is usually no paper, offline judgment is the printer and the server lost contact for more than 30 seconds
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<List<int>> queryPrintersStatus(PrintersRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/queryPrintersStatus";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<List<int>> result = JsonHelper.Json2Object<ObjectRestResponse<List<int>>>(resp);
            return result;
        }

        /// <summary>
        /// 10.Cloud speakers play voice
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<string> playVoice(VoiceRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/playVoice";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<string> result = JsonHelper.Json2Object<ObjectRestResponse<string>>(resp);
            return result;
        }

        /// <summary>
        /// 12.POS instruction
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<string> pos(PrintRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/pos";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<string> result = JsonHelper.Json2Object<ObjectRestResponse<string>>(resp);
            return result;
        }

        /// <summary>
        /// 13. Cash box control
        /// </summary>
        /// <param name="restRequest"></param>
        /// <returns></returns>
        public ObjectRestResponse<String> controlBox(PrintRequest restRequest)
        {
            string url = BASE_URL + "/api/openapi/xprinter/controlBox";
            string jsonRequest = JsonHelper.Object2Json(restRequest);
            HttpHelper httpHelper = new HttpHelper();
            string resp = httpHelper.HttpPostJSON(url, jsonRequest);
            ObjectRestResponse<string> result = JsonHelper.Json2Object<ObjectRestResponse<string>>(resp);
            return result;
        }
    }
}
